.. _tutorials:

###########
 Tutorials
###########

These documents should serve as a way to discover icclim and it's
capabilities. To see how icclim can solve specific issues see
:ref:`how_to`.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   notebooks/averaged_tas_anomaly
   notebooks/deltaT_deltaP_anomaly
   notebooks/tg90p_calculate__subset_and_plot
   notebooks/custom_freezing_tas
   notebooks/cold_spell_duration
   notebooks/su_summer_days__subset_and_plot
   notebooks/DCSC_txnn
